@@ -1,11 +1,15 @@
-from typing import Optional, Union, Dict
+from __future__ import annotations
+
+from typing import Optional, Union, Dict, TYPE_CHECKING
+if TYPE_CHECKING:
+    from .cog import DocItem
 
 
 class DocCache:
     def __init__(self) -> None:
         self.cache = {}
 
-    def set(self, item, value: str) -> None:
+    def set(self, item: DocItem, value: str) -> None:
         """
         Set the Markdown `value` for the symbol `item`.
         All keys from a single page are stored together.
@@ -15,7 +19,7 @@ class DocCache:
             self.cache[item.package] = {}
         self.cache[item.package][item.symbol_id] = value
 
-    def get(self, item) -> Optional[str]:
+    def get(self, item: DocItem) -> Optional[str]:
         """Return the Markdown content of the symbol `item` if it exists."""
 
         key: Union[Dict, None] = self.cache.get(item.package)
